@@ -1,7 +1,7 @@
 # standard Dash imports
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 
 # import for this example
 from pymatgen.core.structure import Structure
@@ -18,11 +18,11 @@ structure = Structure(
     Lattice.cubic(4.2),
     ["Na", "K"],
     [[0, 0, 0], [0.5, 0.5, 0.5]],
-    site_properties={"magmom": [-10, 10]},
+    site_properties={"magmom": [-2, 2]},
 )
 
 # create the Crystal Toolkit component
-structure_component = ctc.StructureMoleculeComponent(structure, id="struct")
+structure_component = ctc.StructureMoleculeComponent(structure, id="my_structure")
 
 # example layout to demonstrate capabilities of component
 my_layout = html.Div(
@@ -39,6 +39,8 @@ my_layout = html.Div(
         structure_component.title_layout(),
         html.H3("Legend Layout"),
         structure_component.legend_layout(),
+        html.H3("Download Layout"),
+        structure_component.download_layout(),
     ]
 )
 
