@@ -5,8 +5,8 @@ from time import sleep
 from pathlib import Path
 
 import dash
-import dash_html_components as html
-import dash_core_components as dcc
+from dash import html
+from dash import dcc
 from dash.dependencies import Input, Output, State
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
