@@ -1,8 +1,8 @@
 import itertools
 from multiprocessing import cpu_count
 
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 import plotly.express as px
 from dash import callback_context
 from dash.dependencies import Input, Output
