@@ -1,8 +1,8 @@
 from typing import Optional
 
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 import dash_table
 import plotly.graph_objs as go
 from dash.dependencies import Input, Output, State
