@@ -1,13 +1,21 @@
+from pathlib import Path
+
+from tempfile import TemporaryDirectory
+
+from base64 import b64encode
+
+import json
 import os
 import re
 import sys
 import warnings
 from collections import OrderedDict
 from itertools import chain, combinations_with_replacement
+from pymatgen.io.vasp.sets import MPRelaxSet
 from typing import Dict, Optional, Tuple, Union
 
 import dash
-import dash_table as dt
+from dash import dash_table as dt
 import numpy as np
 from dash.dependencies import Input, Output, State, MATCH
 from dash.exceptions import PreventUpdate
@@ -18,6 +26,7 @@ from pymatgen.core.composition import Composition
 from pymatgen.core.periodic_table import DummySpecie
 from pymatgen.core.structure import Molecule, Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
+from emmet.core.settings import EmmetSettings
 
 from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.mpcomponent import MPComponent
@@ -66,6 +75,19 @@ class StructureMoleculeComponent(MPComponent):
     # what to show for the title_layout if structure/molecule not loaded
     default_title = "Crystal Toolkit"
 
+    # human-readable label to file extension
+    # downloading Molecules has not yet been added
+    download_options = {
+        "Structure": {
+            "CIF (Symmetrized)": {"fmt": "cif", "symprec": EmmetSettings().SYMPREC},
+            "CIF": {"fmt": "cif"},
+            "POSCAR": {"fmt": "poscar"},
+            "JSON": {"fmt": "json"},
+            "Prismatic": {"fmt": "prismatic"},
+            "VASP Input Set (MPRelaxSet)": {},  # special
+        }
+    }
+
     def __init__(
         self,
         struct_or_mol: Optional[
@@ -86,6 +108,7 @@ class StructureMoleculeComponent(MPComponent):
         hide_incomplete_bonds: bool = DEFAULTS["hide_incomplete_bonds"],
         show_compass: bool = DEFAULTS["show_compass"],
         scene_settings: Optional[Dict] = None,
+        group_by_site_property: Optional[str] = None,
         **kwargs,
     ):
         """
@@ -104,6 +127,8 @@ class StructureMoleculeComponent(MPComponent):
         :param hide_incomplete_bonds: whether to hide or show incomplete bonds
         :param show_compass: whether to hide or show the compass
         :param scene_settings: scene settings (lighting etc.) to pass to CrystalToolkitScene
+        :param group_by_site_property: a site property used for grouping of atoms for mouseover/interaction,
+        e.g. Wyckoff label
         :param kwargs: extra keyword arguments to pass to MPComponent
         """
 
@@ -138,6 +163,7 @@ class StructureMoleculeComponent(MPComponent):
                 "bonded_sites_outside_unit_cell": bonded_sites_outside_unit_cell,
                 "hide_incomplete_bonds": hide_incomplete_bonds,
                 "show_compass": show_compass,
+                "group_by_site_property": group_by_site_property,
             },
         )
 
@@ -389,7 +415,6 @@ class StructureMoleculeComponent(MPComponent):
             [Input(self.id("screenshot_button"), "n_clicks")],
             [State(self.id("scene"), "imageRequest"), State(self.id(), "data")],
         )
-        @cache.memoize()
         def trigger_screenshot(n_clicks, current_requests, struct_or_mol):
             if n_clicks is None:
                 raise PreventUpdate
@@ -408,9 +433,91 @@ class StructureMoleculeComponent(MPComponent):
             return {
                 "n_requests": n_requests,
                 "filename": request_filename,
-                "fileType": "png",
+                "filetype": "png",
             }
 
+        @app.callback(
+            Output(self.id("download"), "data"),
+            Input(self.id("scene"), "imageDataTimestamp"),
+            [
+                State(self.id("scene"), "imageData"),
+                State(self.id("scene"), "imageRequest"),
+            ],
+        )
+        def download_image(image_data_timestamp, image_data, image_request):
+            if not image_data_timestamp:
+                raise PreventUpdate
+
+            return {
+                "content": image_data[len("data:image/png;base64,") :],
+                "filename": image_request["filename"],
+                "base64": True,
+                "type": "image/png",
+            }
+
+        @app.callback(
+            Output(self.id("download-structure"), "data"),
+            Input(self.id("download-button"), "n_clicks"),
+            [
+                State(self.get_kwarg_id("download_option"), "value"),
+                State(self.id(), "data"),
+            ],
+        )
+        def download_structure(n_clicks, download_option, data):
+
+            if not n_clicks:
+                raise PreventUpdate
+
+            structure = self.from_data(data)
+            if isinstance(structure, StructureGraph):
+                structure = structure.structure
+
+            file_prefix = structure.composition.reduced_formula
+
+            download_option = download_option[0]
+
+            if "VASP" not in download_option:
+
+                extension = self.download_options["Structure"][download_option]["fmt"]
+                options = self.download_options["Structure"][download_option]
+
+                try:
+                    contents = structure.to(**options)
+                except Exception as exc:
+                    # don't fail silently, tell user what went wrong
+                    contents = exc
+
+                base64 = b64encode(contents.encode("utf-8")).decode("ascii")
+
+                download_data = {
+                    "content": base64,
+                    "base64": True,
+                    "type": "text/plain",
+                    "filename": f"{file_prefix}.{extension}",
+                }
+
+            else:
+
+                if "Relax" in download_option:
+                    vis = MPRelaxSet(structure)
+                    expected_filename = "MPRelaxSet.zip"
+                else:
+                    raise ValueError("No other VASP input sets currently supported.")
+
+                with TemporaryDirectory() as tmpdir:
+                    vis.write_input(tmpdir, potcar_spec=True, zip_output=True)
+                    path = Path(tmpdir) / expected_filename
+                    bytes = b64encode(path.read_bytes()).decode("ascii")
+
+                download_data = {
+                    "content": bytes,
+                    "base64": True,
+                    "type": "application/zip",
+                    "filename": f"{file_prefix} {expected_filename}",
+                }
+
+            return download_data
+
         @app.callback(
             Output(self.id("title_container"), "children"),
             [Input(self.id("legend_data"), "data")],
@@ -569,13 +676,15 @@ class StructureMoleculeComponent(MPComponent):
     def _sub_layouts(self):
 
         struct_layout = html.Div(
-            CrystalToolkitScene(
-                id=self.id("scene"),
-                data=self.initial_data["scene"],
-                settings=self.initial_scene_settings,
-                sceneSize="100%",
-                **self.scene_kwargs,
-            ),
+            [
+                CrystalToolkitScene(
+                    id=self.id("scene"),
+                    data=self.initial_data["scene"],
+                    settings=self.initial_scene_settings,
+                    sceneSize="100%",
+                    **self.scene_kwargs,
+                ),
+            ],
             style={
                 "width": "100%",
                 "height": "100%",
@@ -590,7 +699,8 @@ class StructureMoleculeComponent(MPComponent):
                     [Icon(kind="download"), html.Span(), "Download Image"],
                     kind="primary",
                     id=self.id("screenshot_button"),
-                )
+                ),
+                dcc.Download(id=self.id("download")),
             ],
             # TODO: change to "bottom" when dropdown included
             style={"verticalAlign": "top", "display": "inline-block"},
@@ -773,12 +883,45 @@ class StructureMoleculeComponent(MPComponent):
             ]
         )
 
+        state = {"fmt": "CIF (Symmetrized)"}
+
+        download_options = self.get_choice_input(
+            kwarg_label="download_option",
+            state=state,
+            options=[
+                {"label": k, "value": k}
+                for k, v in self.download_options["Structure"].items()
+            ],
+            style={
+                "border-radius": "4px 0px 0px 4px",
+                "width": "12rem",
+                "height": "1.5rem",
+            },
+        )
+
+        download_button = Button(
+            [Icon(kind="download"), html.Span(), "Download"],
+            kind="primary",
+            id=self.id("download-button"),
+            style={"height": "2.25rem"},
+        )
+
+        download_layout = html.Div(
+            [
+                html.Div([download_options], className="control"),
+                html.Div([download_button], className="control"),
+                dcc.Download(id=self.id("download-structure")),
+            ],
+            className="field has-addons",
+        )
+
         return {
             "struct": struct_layout,
             "screenshot": screenshot_layout,
             "options": options_layout,
             "title": title_layout,
             "legend": legend_layout,
+            "download": download_layout,
         }
 
     def layout(self, size: str = "500px") -> html.Div:
@@ -915,6 +1058,7 @@ class StructureMoleculeComponent(MPComponent):
         explicitly_calculate_polyhedra_hull=False,
         scene_additions=None,
         show_compass=DEFAULTS["show_compass"],
+        group_by_site_property=None,
     ) -> Tuple[Scene, Dict[str, str]]:
 
         scene = Scene(name="StructureMoleculeComponentScene")
@@ -938,6 +1082,7 @@ class StructureMoleculeComponent(MPComponent):
                 bonded_sites_outside_unit_cell=bonded_sites_outside_unit_cell,
                 hide_incomplete_edges=hide_incomplete_bonds,
                 explicitly_calculate_polyhedra_hull=explicitly_calculate_polyhedra_hull,
+                group_by_site_property=group_by_site_property,
                 legend=legend,
             )
         elif isinstance(graph, MoleculeGraph):
@@ -950,12 +1095,13 @@ class StructureMoleculeComponent(MPComponent):
             axes.visible = show_compass
             scene.contents.append(axes)
 
-        if scene_additions:
-            # TODO: need a Scene.from_json() to make this work
-            raise NotImplementedError
-            scene["contents"].append(scene_additions)
+        scene_json = scene.to_json()
 
-        return scene.to_json(), legend.get_legend()
+        if scene_additions:
+            # TODO: this might be cleaner if we had a Scene.from_json() method
+            scene_json["contents"].append(scene_additions)
+
+        return scene_json, legend.get_legend()
 
     def screenshot_layout(self):
         """
@@ -980,3 +1126,9 @@ class StructureMoleculeComponent(MPComponent):
         :return: A layout including a legend for the structure/molecule.
         """
         return self._sub_layouts["legend"]
+
+    def download_layout(self):
+        """
+        :return: A layout including a download button to download the structure/molecule.
+        """
+        return self._sub_layouts["download"]
