@@ -8,9 +8,9 @@ from typing import Dict, List, Optional, Set, Tuple, Union
 from base64 import b64encode
 
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
-import dash_table as dt
+from dash import dcc
+from dash import html
+from dash import dash_table as dt
 import numpy as np
 from dash.dependencies import ALL, Output
 from flask_caching import Cache
@@ -210,6 +210,8 @@ class MPComponent(ABC):
         # Note: shadowing Python built-in here, but only because Dash does it...
         # TODO: do something else here
         if id is None:
+            # TODO: this could lead to duplicate ids and an error, but if
+            # setting random ids, this could also lead to undefined behavior
             id = f"{CT_NAMESPACE}{self.__class__.__name__}"
         elif not id.startswith(CT_NAMESPACE):
             id = f"{CT_NAMESPACE}{id}"
@@ -440,6 +442,8 @@ Sub-layouts:  \n{layouts}"""
         def matrix_element(idx, value=0):
             # TODO: maybe move element out of the name
             mid = self.id(kwarg_label, is_kwarg=True, idx=idx, hint=shape)
+            if isinstance(value, np.ndarray):
+                value = value.item()
             if not is_int:
                 return dcc.Input(
                     id=mid,
@@ -454,7 +458,7 @@ Sub-layouts:  \n{layouts}"""
                         "marginBottom": "0.2rem",
                         "height": "36px",
                     },
-                    value=value,
+                    value=float(value) if value is not None else None,
                     persistence=True,
                     type="number",
                     **kwargs,
@@ -473,7 +477,7 @@ Sub-layouts:  \n{layouts}"""
                         "marginBottom": "0.2rem",
                         "height": "36px",
                     },
-                    value=value,
+                    value=int(value) if value is not None else None,
                     persistence=True,
                     type="number",
                     step=1,
@@ -677,33 +681,48 @@ Sub-layouts:  \n{layouts}"""
 
             # TODO: catch Exceptions here, and display validation error to user if incorrect kwargs supplied
 
-            if isinstance(k_type, tuple):
-                # matrix or vector
-                if kwarg_label not in kwargs:
-                    kwargs[kwarg_label] = np.empty(k_type)
-                v = literal_eval(str(v))
-                if v is not None and kwargs[kwarg_label] is not None:
-                    kwargs[kwarg_label][idx] = literal_eval(str(v))
-                else:
-                    # require all elements to have value, otherwise set
-                    # entire kwarg to None
-                    kwargs[kwarg_label] = None
+            try:
 
-            elif k_type == "literal":
+                if isinstance(k_type, tuple):
+                    # matrix or vector
+                    if kwarg_label not in kwargs:
+                        kwargs[kwarg_label] = np.empty(k_type)
+                    v = literal_eval(str(v))
+                    if (v is not None) and (kwargs[kwarg_label] is not None):
+                        if isinstance(v, list):
+                            print(
+                                "This shouldn't happen! Debug required.",
+                                kwarg_label,
+                                idx,
+                                v,
+                            )
+                            kwargs[kwarg_label][idx] = None
+                        else:
+                            kwargs[kwarg_label][idx] = v
+                    else:
+                        # require all elements to have value, otherwise set
+                        # entire kwarg to None
+                        kwargs[kwarg_label] = None
 
-                try:
-                    kwargs[kwarg_label] = literal_eval(str(v))
-                except ValueError:
-                    kwargs[kwarg_label] = str(v)
+                elif k_type == "literal":
 
-            elif k_type == "bool":
-                kwargs[kwarg_label] = bool("enabled" in v)
+                    try:
+                        kwargs[kwarg_label] = literal_eval(str(v))
+                    except ValueError:
+                        kwargs[kwarg_label] = str(v)
 
-            elif k_type == "slider":
-                kwargs[kwarg_label] = v
+                elif k_type == "bool":
+                    kwargs[kwarg_label] = bool("enabled" in v)
 
-            elif k_type == "dict":
-                pass
+                elif k_type == "slider":
+                    kwargs[kwarg_label] = v
+
+                elif k_type == "dict":
+                    pass
+
+            except Exception as exc:
+                # Not raised intentionally but if you notice this in logs please investigate.
+                print("This is a problem, debug required.", exc)
 
         for k, v in kwargs.items():
             if isinstance(v, np.ndarray):
